@@ -5,4 +5,4 @@ from baseflow.param_estimate import *
 from baseflow.comparision import *
 from baseflow.utils import *
 
-_path = os.path.dirname(__file__)
+example = os.path.join(os.path.dirname(__file__), 'example.csv')
