@@ -19,21 +19,24 @@ def load_streamflow(path):
         month = date.astype('datetime64[M]').astype(int) % 12 + 1
         day = (date - date.astype('datetime64[M]')).astype(int) + 1
         date = np.rec.fromarrays([year, month, day], dtype=[('Y', 'i4'), ('M', 'i4'), ('D', 'i4')])
-    else:
+    elif len(path.shape) > 1:
         df_date = path.iloc[:, 0].astype('datetime64')
         date = np.rec.fromarrays([df_date.dt.year, df_date.dt.month, df_date.dt.day],
                                  dtype=[('Y', 'i4'), ('M', 'i4'), ('D', 'i4')])
         Q = path.iloc[:, 1].values.astype(float)
+    else:
+        date = np.rec.fromarrays([path.index.year, path.index.month, path.index.day],
+                                 dtype=[('Y', 'i4'), ('M', 'i4'), ('D', 'i4')])
+        Q = path.values.astype(float)
     return clean_streamflow(date, Q)
 
 
 def clean_streamflow(date, Q):
-    Q[np.isnan(Q)] = 0
     Q = np.abs(Q)
     year = date['Y']
     year_unique = np.unique(year)
     year_delete = clean_streamflow_jit(year, year_unique, Q)
-    idx_delete = np.isin(year, year_delete)
+    idx_delete = np.isin(year, year_delete) | np.isnan(Q)
     return Q[~idx_delete], date[~idx_delete]
 
 
@@ -46,6 +49,25 @@ def clean_streamflow_jit(year, year_unique, Q):
     return year_delete
 
 
+def exist_ice(date, ice_period):
+    if (date is None) or (ice_period is None):
+        return None
+
+    if isinstance(ice_period, np.ndarray):
+        return np.isin(date.M, np.where(ice_period)[0] + 1)
+
+    beg, end = ice_period
+    if (end[0] > beg[0]) or ((end[0] == beg[0]) & (end[1] > beg[1])):
+        ice = (((date.M > beg[0]) & (date.M < end[0])) |
+               ((date.M == beg[0]) & (date.D >= beg[1])) |
+               ((date.M == end[0]) & (date.D <= end[1])))
+    else:
+        ice = (((date.M > beg[0]) | (date.M < end[0])) |
+               ((date.M == beg[0]) & (date.D >= beg[1])) |
+               ((date.M == end[0]) & (date.D <= end[1])))
+    return ice
+
+
 def moving_average(x, w):
     res = np.convolve(x, np.ones(w)) / w
     return res[w - 1:-w + 1]
